<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt" xmlns:pi="http://www.ibm.com" xmlns:platformInfo="com.ibm.ci.invtool.core.Resources" extension-element-prefixes="platformInfo">
	<xsl:output method="text" />
	<xsl:param name="delimiter" select=" ',' " />
    <xsl:template match="/">
	    
		<xsl:for-each select="pi:Platform/systemInformation">
            <xsl:call-template name="info">
				<xsl:with-param name="value" select="hostname" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="domain" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="operatingSystem/type" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="operatingSystem/version" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="memory" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="processorSpeed" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="cpuCount" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="osRoot" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="locale" />
				<xsl:with-param name="noDelimiter" select="'true'" />

			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:for-each select="pi:Platform/installedProduct">
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="name" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="version" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="productRoot" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="buildLevel" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="value" select="buildDate" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="node" select="RSUs" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="node" select="fixPacksOrCSDs" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="node" select="PTFs" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="node" select="interimFixes" />
				<xsl:with-param name="noDelimiter" select="'true'" />
			</xsl:call-template>
			<xsl:text></xsl:text>
		</xsl:for-each>
	</xsl:template>
 
    <xsl:template name="info">
		<xsl:param name="value" />
        <xsl:param name="noDelimiter" />
        
        <xsl:value-of select="platformInfo:toCSVString($value)" />
        <xsl:choose>
                <xsl:when test="$noDelimiter='true'"> 
                    <xsl:text>&#xA;</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$delimiter" />
                </xsl:otherwise>
        </xsl:choose>
   	</xsl:template>

	<xsl:template name="list">
		<xsl:param name="node" />
        <xsl:param name="noDelimiter" />
		<xsl:choose>
			<xsl:when test="$node/@discoverable='false'">
				<xsl:call-template name="info">
					<xsl:with-param name="value" select="platformInfo:getString('label.is.absent')" />
                    <xsl:with-param name="noDelimiter" select="$noDelimiter" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="count($node/*)=0">
						<xsl:call-template name="info">
							<xsl:with-param name="value" select="platformInfo:getString('label.none')" />
                            <xsl:with-param name="noDelimiter" select="$noDelimiter" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
                        <xsl:if test="count($node/*)>1">
                            <xsl:text>"</xsl:text>
                        </xsl:if>
						<xsl:for-each select="$node/*">
							<xsl:value-of select="." />
							<xsl:if test="position() != last()">
								<xsl:text>, </xsl:text>
							</xsl:if>
						</xsl:for-each>
                        <xsl:if test="count($node/*)>1">
                            <xsl:text>"</xsl:text>
                        </xsl:if>
                        <xsl:choose>
                            <xsl:when test="$noDelimiter='true'"> 
                                <xsl:text>&#xA;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$delimiter" />
                            </xsl:otherwise>
                        </xsl:choose>					
                    </xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>