<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt" xmlns:pi="http://www.ibm.com">
	<xsl:output method="text" />
	<xsl:template match="/">
		<xsl:text>--------------------------------------------------------------------------------&#xA;</xsl:text>
		<xsl:text>Level Reporting Tool for the WebSphere Platform Product Installation Status Report</xsl:text>
		<xsl:text>&#xA;--------------------------------------------------------------------------------&#xA;&#xA;</xsl:text>
		
		<xsl:call-template name="header">
			<xsl:with-param name="time" select="pi:Platform/generationTime" />
		</xsl:call-template>
		
		<xsl:for-each select="pi:Platform/systemInformation">
			<xsl:text>&#xA;</xsl:text>
			<xsl:text>System Information</xsl:text>
			<xsl:text>&#xA;-------------------------------------------------------------------------------&#xA;</xsl:text>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Hostname'" />
				<xsl:with-param name="value" select="hostname" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Domain'" />
				<xsl:with-param name="value" select="domain" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Operating System'" />
				<xsl:with-param name="value" select="operatingSystem/type" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Version'" />
				<xsl:with-param name="value" select="operatingSystem/version" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Memory'" />
				<xsl:with-param name="value" select="memory" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Processor Speed (Mhz)'" />
				<xsl:with-param name="value" select="processorSpeed" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Number of CPUs'" />
				<xsl:with-param name="value" select="cpuCount" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'OS root'" />
				<xsl:with-param name="value" select="osRoot" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Locale'" />
				<xsl:with-param name="value" select="locale" />
			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:for-each select="pi:Platform/installedProduct">
			<xsl:text>&#xA;</xsl:text>
			<xsl:value-of select="'Installed Product'" />
			<xsl:text>&#xA;--------------------------------------------------------------------------------&#xA;</xsl:text>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Name'" />
				<xsl:with-param name="value" select="name" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Version'" />
				<xsl:with-param name="value" select="version" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Product Root'" />
				<xsl:with-param name="value" select="productRoot" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Build Level'" />
				<xsl:with-param name="value" select="buildLevel" />
			</xsl:call-template>
			<xsl:call-template name="info">
				<xsl:with-param name="label" select="'Build Date'" />
				<xsl:with-param name="value" select="buildDate" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="label" select="'RSU(s) Applied'" />
				<xsl:with-param name="node" select="RSUs" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="label" select="'FixPacks or CSDs Applied'" />
				<xsl:with-param name="node" select="fixPacksOrCSDs" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="label" select="'PTFs Applied'" />
				<xsl:with-param name="node" select="PTFs" />
			</xsl:call-template>
			<xsl:call-template name="list">
				<xsl:with-param name="label" select="'Interim/Test Fixes Applied'" />
				<xsl:with-param name="node" select="interimFixes" />
			</xsl:call-template>
			<xsl:text></xsl:text>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="header">
		<xsl:param name="time" />
		<xsl:text>Report at date and time </xsl:text>
		<xsl:value-of select="string($time)" />
		<xsl:text>&#xA;</xsl:text>
		<xsl:text>&#xA;</xsl:text>
	</xsl:template>
	
	<xsl:template name="info">
		<xsl:param name="label" />
		<xsl:param name="value" />
		<xsl:value-of select="$label" />
		<xsl:text>: </xsl:text>
		<xsl:value-of select="$value" />
		<xsl:text>&#xA;</xsl:text>
	</xsl:template>

	<xsl:template name="list">
		<xsl:param name="label" />
		<xsl:param name="node" />
		<xsl:choose>
			<xsl:when test="$node/@discoverable='false'">
				<xsl:call-template name="info">
					<xsl:with-param name="label" select="$label" />
					<xsl:with-param name="value" select="'N/A'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="count($node/*)=0">
						<xsl:call-template name="info">
							<xsl:with-param name="label" select="$label" />
							<xsl:with-param name="value" select="'none'" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$label" />
						<xsl:text>: </xsl:text>
						<xsl:for-each select="$node/*">
							<xsl:value-of select="." />
							<xsl:if test="position() != last()">
								<xsl:text>, </xsl:text>
							</xsl:if>
						</xsl:for-each>
						<xsl:text>&#xA;</xsl:text>
						<xsl:text></xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>